@@ -7,25 +7,19 @@
 #include "sys-defines.h"
 #include "extern.h"
 
-int
+bool
 #ifdef _HAVE_PROTOS
-_x_flushpl (S___(Plotter *_plotter))
+_x_flush_output (S___(Plotter *_plotter))
 #else
-_x_flushpl (S___(_plotter))
+_x_flush_output (S___(_plotter))
      S___(Plotter *_plotter;)
 #endif
 {
-  if (!_plotter->open)
-    {
-      _plotter->error (R___(_plotter) "flushpl: invalid operation");
-      return -1;
-    }
-
   XSync (_plotter->x_dpy, (Bool)false);
 
   /* maybe flush X output buffer and handle X events (a no-op for
      XDrawablePlotters, which is overridden for XPlotters) */
   _maybe_handle_x_events (S___(_plotter));
 
-  return 0;
+  return true;
 }
